"""Example usage of pykmtronic."""
import asyncio
import aiohttp
import time
import logging

from pykmtronic.auth import Auth
from pykmtronic.hub import KMTronicHubAPI

logging.basicConfig(level=logging.DEBUG)


async def main():
    async with aiohttp.ClientSession() as session:
        auth = Auth(session, "http://192.168.1.160", "admin", "admin")
        api = KMTronicHubAPI(auth)

        relays = await api.async_get_relays()

        r = relays[0]

        print("is relay1 ON?", r.is_energised)
        await r.energise()
        time.sleep(2)
        print("is relay1 ON?", r.is_energised)

        await r.de_energise()
        time.sleep(2)
        await api.async_update_relays()
        print("is relay1 ON?", r.is_energised)


        time.sleep(2)
        await r.toggle()
        time.sleep(2)
        await api.async_update_relays()
        print("is relay1 ON?", r.is_energised)
        time.sleep(2)
        await r.toggle()
        time.sleep(2)
        await api.async_update_relays()
        print("is relay1 ON?", r.is_energised)

asyncio.run(main())



from setuptools import setup, find_packages
import pykmtronic

long_description = open('README.md').read()

setup(
    name='pykmtronic',
    version=pykmtronic.__version__,
    license='MIT License',
    url='https://github.com/dgomes/pykmtronic',
    author='Diogo Gomes',
    author_email='diogogomes@gmail.com',
    description='Python library to interface with KM Tronic Web Relays',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=['pykmtronic'],
    zip_safe=True,
    platforms='any',
    install_requires=[
        'aiohttp',
        'lxml',
      ],
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)


"""Representation of a single relay."""
from pykmtronic.auth import Auth
import logging

logger = logging.getLogger(__name__)


class Relay:
    """Relay Object."""

    def __init__(self, number: int, status: bool, auth: Auth):
        """Relay constructor."""
        self._relay = number
        self.auth = auth
        self.is_energised = status  # True means energised/ON

    @property
    def id(self) -> int:
        """Id of the relay, position of the relay in the device."""
        return self._relay

    @property
    def is_energised(self):
        """Wether the relay is energised (ON/True) or not (OFF/False)."""
        return self._is_energised

    @is_energised.setter
    def is_energised(self, b):
        """Set state variable _is_energised."""
        logger.debug(
            f"Relay{self._relay} is now {'Energised' if b else 'De-energised'}"
        )
        self._is_energised = b

    async def energise(self):
        """Energises the relay connecting COM to NO."""
        logger.debug(f"Sending ... FF{self._relay:02}01")
        resp = await self.auth.request(f"FF{self._relay:02}01")
        resp.raise_for_status()
        self.is_energised = True

    async def de_energise(self):
        """De-energises the relay connecting COM to NO."""
        logger.debug(f"Sending ... FF{self._relay:02}00")
        resp = await self.auth.request(f"FF{self._relay:02}00")
        resp.raise_for_status()
        self.is_energised = False

    async def toggle(self):
        """Toggle the relay."""
        logger.debug(f"Calling relays.cgi?relay={self._relay}")
        resp = await self.auth.request(f"relays.cgi?relay={self._relay}")
        resp.raise_for_status()
        self.is_energised = not self.is_energised
